#!/bin/sh

# All Rights Reserved.
# Copyright (C) 2006,2008, Hitachi, Ltd.

############################################################
# Functions

# Answer check subroutine
chk_YesNo()
{
    while [ 1 ]
    do
        echo -n "(y|n[n]) : "
        read ANS
        case $ANS in
          Y|y)
            return 0
            ;;
          N|n|*)
            return 1
            ;;
        esac
    done
}

############################################################
# Main function
PRODUCT_NAME=MiACAT
CD_DIR=`which $0 | sed 's/\/[^/]*$//'`
CD_DATA_DIR="${CD_DIR}/INST_DATA"

. ${CD_DIR}/version

echo "--------------------------------------------------------------"
echo " ${PRODUCT_NAME} Ver ${VERSION} Installer."
echo "   All Rights Reserved. Copyright (C) 2006,2008, Hitachi, Ltd."
echo "--------------------------------------------------------------"

if [ `whoami` != "root" ]
then
    echo "Failed."
    echo "You are not root user."
    echo "Installation was canceled."
    exit 1
fi

ARCH="ia32"
if [ `uname -i` == "ia64" ]
then
    ARCH="ipf"
fi

INST_DIR="/opt/H_Densa/SMAL2"
INST_VAR="/var/H_Densa/SMAL2/Temp/MainteAgtTmp"
CONF_FILE=${INST_DIR}/MainteData/smal2.conf
PIPE_FILE=${INST_DIR}/Program/SyslogPipe
MREG_FILE=${INST_DIR}/Program/MRegCUI
RC_FILE=smal2d
RC_FILE_FROM=${CD_DATA_DIR}/${RC_FILE}
RC_FILE_TO=/etc/rc.d/init.d/${RC_FILE}
UNINSTALLER_FROM=${CD_DIR}/uninstall.sh
UNINSTALLER_TO=${INST_DIR}/uninstall.sh

if [ -d ${INST_DIR} ]
then
    # Uninstall function
    #echo "'${PRODUCT_NAME}' is already installed."
    #echo "Do you uninstall '${PRODUCT_NAME}' ?"
    #if ! chk_YesNo
    #then
    #    echo "Installation was canceled."
    #    exit 1
    #fi
    #if [ -f ${RC_FILE_TO} ]
    #then
    #    ${RC_FILE_TO} stop > /dev/null
    #    chkconfig --del ${RC_FILE}
    #    rm -f  ${RC_FILE_TO}
    #fi
    #rm -rf ${INST_DIR}
    #echo "Uninstallation was completed."
    
    if [ -f ${RC_FILE_TO} ]
    then
        echo "'${PRODUCT_NAME}' is already installed."
        echo "Installation was canceled."
        exit 1
    fi
    rm -rf ${INST_DIR}
fi

##############################
# Check Red Hat version
RHEL_VER=
grep -q "\(AS\|ES\) release 3" /etc/redhat-release
if [ $? -eq 0 ]; then
	RHEL_VER=rhel_as3
fi
grep -q "\(AS\|ES\) release 4" /etc/redhat-release
if [ $? -eq 0 ]; then
	RHEL_VER=rhel_as4
fi
grep -q "release 5" /etc/redhat-release
if [ $? -eq 0 ]; then
	RHEL_VER=rhel_as4
fi

if [ -z "${RHEL_VER}" ]; then
	echo "Target version"
	echo " 1. Red Hat Enterprise Linux release 3"
	echo " 2. Red Hat Enterprise Linux release 4"
	echo " 3. Red Hat Enterprise Linux release 5"
	echo
	while [ 1 ]
	do
	    echo -n "(1-3,q) : "
	    read ANS
	    case $ANS in
	      1)
	        RHELVER="rhel_as3"
	        break
	        ;;
	      2)
	        RHELVER="rhel_as4"
	        break
	        ;;
	      3)
	        RHELVER="rhel_as4"
	        break
	        ;;
	      q|Q)
	        echo "Installation was canceled."
	        exit 1
	        ;;
	    esac
	done
else
	RHELVER=${RHEL_VER}
fi

##############################
# Check JP1/SC-Agent version
CHECK_SCVER="081802"
SCVERFILE=/var/opt/hitachi/system_manager/log/version
if [ ! -f ${SCVERFILE} ]; then
    echo "Failed."
	echo "JP1/SC-Agent is not installed."
	echo "Please install JP1/SC-Agent earlier."
	exit 1
fi
SCVER=`grep "server_agent_version" ${SCVERFILE} | cut -f2 -d" "`
if [ -z "${SCVER}" -o "${SCVER}" \< "${CHECK_SCVER}" ]; then
    echo "Failed."
	echo "A version of the JP1/SC-Agent is old."
	echo "Please install higher than version '${CHECK_SCVER}' of the JP1/SC-Agent."
	exit 1
fi

##############################
# Check Machine
MACHINE_ID="BS-${ARCH}"

# which dmidecode 2> /dev/null
# if [ $? -eq 0 ]
# then
#     PRODUCT_NAME=`dmidecode | sed -n '/System Information/,/Handle/p' | grep "Product Name:" | sed 's/^.*: *//g'`
#     echo "${PRODUCT_NAME}" | grep "BladeSymphony" > /dev/null
#     if [ $? -eq 0 ]
#     then
#         MACHINE_ID="BS-${ARCH}"
#     fi
# else
#     echo "TargetMachine"
#     echo " 1. BS"
#     echo " 2. HA8000"
#     echo
#     while [ 1 ]
#     do
#         echo -n "(1-2,q) : "
#         read ANS
#         case $ANS in
#           1)
#             MACHINE_ID="BS-${ARCH}"
#             break
#             ;;
#           2)
#             break
#             ;;
#           q|Q)
#             echo "Installation was canceled."
#             exit 1
#             ;;
#         esac
#     done
# fi

#CONF_FILE_FROM=${CD_DATA_DIR}/smal2.${MACHINE_ID}.conf
#ALERT_FILE_FROM=${CD_DATA_DIR}/RmtReport.${MACHINE_ID}.csv

##############################
# Confirm installation
echo "A package for ${MACHINE_ID} is installed."
echo "Do you install '${PRODUCT_NAME}' ?"
if ! chk_YesNo
then
    echo "Installation was canceled."
    exit 1
fi

##############################
INSTFILEBASE=${CD_DATA_DIR}/SMAL2.base.tgz
INSTFILE=${CD_DATA_DIR}/SMAL2.${ARCH}.${RHELVER}.tgz

##############################
# Copy file
echo "Copy file ..."
mkdir -p ${INST_VAR}
mkdir -p ${INST_DIR}
(cd ${INST_DIR} && tar xzf ${INSTFILEBASE})
(cd ${INST_DIR} && tar xzf ${INSTFILE})
cp -f ${CD_DIR}/version   ${INST_DIR}/
cp -f ${UNINSTALLER_FROM} ${UNINSTALLER_TO}
cp -f ${RC_FILE_FROM}     ${RC_FILE_TO}
chmod 0755 ${RC_FILE_TO} ${UNINSTALLER_TO}
chcon root:object_r:syslogd_tmp_t ${PIPE_FILE} > /dev/null 2>&1

##############################
# Install daemon
echo "Install daemon ..."
chkconfig --add ${RC_FILE}

##############################
# Setup of syslogd. (edit syslog.conf)
echo "Setup of syslogd ..."
echo -e "# [MIACAT] MIACAT syslog watch"   >> /etc/syslog.conf
echo -e "kern.*;daemon.*;user.*\t\t|${PIPE_FILE}" >> /etc/syslog.conf
(cd /; /etc/init.d/syslog restart)

##############################
# Start daemon
echo "Start daemon ..."
(cd /; /etc/init.d/smal2d start)
sleep 1

##############################
# Confirm connection to SVP. (need setup of SVP address)
#echo "Set SVP address ..."
#while [ 1 ]
#do
#    ${MREG_FILE}
#    SVPIP=`sed -n "/^\[SOFTWARE[\]H_Densa[\]SMAL2[\]Maintenance Agent Service[\]SvpInfo\]/,/^\[/p" ${CONF_FILE} | grep "Address=" | cut -f2 -d=`
#    if [ -n "${SVPIP}" ]
#    then
#        break
#    fi
#    echo "WARNING!! - SVP address is not set up. !"
#    echo ""
#    echo -n "Do you do setup of SVP later ? "
#    if chk_YesNo
#    then
#        break
#    fi
#done

echo "Installation was completed."

exit 0
